<template>
  <ModalDialog
    ref="updateModal"
    is-page
    @close="$router.push({ name: 'admin.domains' })"
  >
    <ModalHeader>
      <ModalTitle>{{ $t("app.admin.domains.update.title") }}</ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <FormInput
          id="domain"
          :errors="form.errors.domain"
        >
          <FormLabel>{{ $t("app.admin.domains.form.domain") }}</FormLabel>
          <FormText
            v-model="form.values.domain"
            name="domain"
            required
          />
        </FormInput>
        <FormInput
          id="redirect"
          :errors="form.errors.redirect"
        >
          <FormLabel>{{ $t("app.admin.domains.form.redirect") }}</FormLabel>
          <FormText
            v-model="form.values.redirect"
            name="redirect"
          />
        </FormInput>
      </template>
      <template #footer>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-black"
        >
          {{ $t("app.admin.domains.update.submit") }}
        </FormSubmit>
        <DomainDeleteModal
          v-if="hasPermission(Permission.ADMIN_DOMAINS_DELETE)"
          :id="String($route.params.id)"
          v-slot="{ open }"
          @confirm="onDeleted"
        >
          <button
            class="btn btn-outline-red"
            type="button"
            @click="open"
          >
            <ButtonIcon :icon="TrashCanRegularIcon">
              {{ $t("app.admin.domains.delete.title") }}
            </ButtonIcon>
          </button>
        </DomainDeleteModal>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script setup lang="ts">
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useNotification from "@/js/contexts/shared/composables/useNotification";
import useAuth from "@/js/contexts/auth/composables/useAuth";
import useModal from "@/js/contexts/shared/composables/useModal";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import useForm from "@/js/contexts/shared/composables/useForm";
import type { DomainUpdate } from "@/js/contexts/shared/models/Domain";
import { Permission } from "@/js/contexts/shared/models/Permission";
import ButtonIcon from "@/js/contexts/shared/ui/components/button/ButtonIcon.vue";
import TrashCanRegularIcon from "@/svg/icons/trash-can-regular.svg?component";
import DomainDeleteModal from "@/js/contexts/admin/domains/ui/modals/DomainDeleteModal.vue";

type Response = { domain: string; redirect: string };

const emit = defineEmits<{
  fetch: [];
}>();

const { t } = useI18n();
const { successNotification } = useNotification();
const { hasPermission } = useAuth();
const updateModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(updateModal);
const route = useRoute();
const domainFetch = useFetch(`/api/admin/domains/${route.params.id}`, { isFetching: true });

const form = useForm<DomainUpdate>({
  domain: "",
  redirect: "",
});

onMounted(() => {
  domainFetch.get<Response>().then((response) => {
    form.values.domain = response.data.domain;
    form.values.redirect = response.data.redirect;
    form.updatedValues();
  });
});

const submit = () => {
  form.put(`/api/admin/domains/${route.params.id}`, {
    onSuccess: () => {
      emit("fetch");
      modal.close();
      successNotification(t("app.admin.domains.update.success"));
    },
  });
};
const onDeleted = () => {
  emit("fetch");
  modal.close();
};
</script>
